@@ -1,16 +1,16 @@
-#![cfg(all(
-    any(feature = "2d", feature = "3d"),
-    not(all(feature = "2d", feature = "3d")),
-))]
+#![cfg(any(dim2, dim3))]
+
+use std::time::Duration;
 
 use bevy::core::CorePlugin;
 use bevy::prelude::*;
 use bevy::reflect::TypeRegistryArc;
 
 use heron_core::{CollisionLayers, CollisionShape, PhysicsLayer, PhysicsSteps, RigidBody};
-use heron_rapier::rapier::geometry::ColliderSet;
 use heron_rapier::RapierPlugin;
-use std::time::Duration;
+use utils::*;
+
+mod utils;
 
 enum TestLayer {
     A,
@@ -18,14 +18,14 @@ enum TestLayer {
 }
 
 impl PhysicsLayer for TestLayer {
-    fn to_bits(&self) -> u16 {
+    fn to_bits(&self) -> u32 {
         match self {
             TestLayer::A => 1,
             TestLayer::B => 2,
         }
     }
 
-    fn all_bits() -> u16 {
+    fn all_bits() -> u32 {
         3
     }
 }
@@ -62,7 +62,8 @@ fn sets_the_collision_groups() {
     let colliders = app.world.get_resource::<ColliderSet>().unwrap();
     let collider = colliders.get(*app.world.get(entity).unwrap()).unwrap();
 
-    assert_eq!(collider.collision_groups().0, (1 << 16) + 2)
+    assert_eq!(collider.collision_groups().memberships, 1);
+    assert_eq!(collider.collision_groups().filter, 2);
 }
 
 #[test]
@@ -92,7 +93,8 @@ fn updates_the_collision_groups() {
     let colliders = app.world.get_resource::<ColliderSet>().unwrap();
     let collider = colliders.get(*app.world.get(entity).unwrap()).unwrap();
 
-    assert_eq!(collider.collision_groups().0, (1 << 16) + 2)
+    assert_eq!(collider.collision_groups().memberships, 1);
+    assert_eq!(collider.collision_groups().filter, 2);
 }
 
 #[test]
@@ -121,5 +123,5 @@ fn restore_the_collision_groups_on_removal() {
     let colliders = app.world.get_resource::<ColliderSet>().unwrap();
     let collider = colliders.get(*app.world.get(entity).unwrap()).unwrap();
 
-    assert_eq!(collider.collision_groups().0, u32::MAX)
+    assert_eq!(collider.collision_groups().memberships, u32::MAX)
 }
